package com.ruoyi.platform.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.platform.domain.PlatformFollower;
import com.ruoyi.platform.service.IPlatformFollowerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 粉丝Controller
 *
 * @author ruoyi
 * @date 2023-01-13
 */
@RestController
@RequestMapping("/platform/follower")
public class PlatformFollowerController extends BaseController {
    @Autowired
    private IPlatformFollowerService platformFollowerService;

    /**
     * 查询粉丝列表
     */
    @PreAuthorize("@ss.hasPermi('platform:follower:list')")
    @GetMapping("/list/{userId}")
    public TableDataInfo list(@PathVariable Long userId) {
        if (userId != null) {
            startPage();
            List<PlatformFollower> list = platformFollowerService.selectPlatformFollowerList(userId);
            return getDataTable(list);
        } else {
            TableDataInfo info = new TableDataInfo();
            info.setCode(400);
            info.setMsg("参数不合法，userId不能为空！");
            return info;
        }
    }

    /**
     * 导出粉丝列表
     */
    @PreAuthorize("@ss.hasPermi('platform:follower:export')")
    @Log(title = "粉丝", businessType = BusinessType.EXPORT)
    @PostMapping("/export/{userId}")
    public void export(HttpServletResponse response, @PathVariable Long userId) {
        List<PlatformFollower> list = platformFollowerService.selectPlatformFollowerList(userId);
        ExcelUtil<PlatformFollower> util = new ExcelUtil<>(PlatformFollower.class);
        util.exportExcel(response, list, "粉丝数据");
    }

    /**
     * 获取粉丝详细信息
     */
    @PreAuthorize("@ss.hasPermi('platform:follower:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(platformFollowerService.selectPlatformFollowerById(id));
    }

    /**
     * 新增粉丝
     */
    @PreAuthorize("@ss.hasPermi('platform:follower:add')")
    @Log(title = "粉丝", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PlatformFollower platformFollower) {
        return toAjax(platformFollowerService.insertPlatformFollower(platformFollower));
    }

    /**
     * 修改粉丝
     */
    @PreAuthorize("@ss.hasPermi('platform:follower:edit')")
    @Log(title = "粉丝", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PlatformFollower platformFollower) {
        return toAjax(platformFollowerService.updatePlatformFollower(platformFollower));
    }

    /**
     * 删除粉丝
     */
    @PreAuthorize("@ss.hasPermi('platform:follower:remove')")
    @Log(title = "粉丝", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(platformFollowerService.deletePlatformFollowerByIds(ids));
    }
}
