package com.ruoyi.web.controller.platform.store.account;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.constant.Constants;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.service.StoreLoginService;
import com.ruoyi.store.domain.StoreAccount;
import com.ruoyi.store.domain.vo.StoreAccountVo;
import com.ruoyi.store.service.IStoreAccountService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 店家账号Controller
 *
 * @author ruoyi
 * @date 2023-02-10
 */
@RestController
@RequestMapping("/platform/store/account")
public class PlatformStoreAccountController extends BaseController {
    @Autowired
    private IStoreAccountService platformStoreAccountService;

    @Autowired
    private StoreLoginService loginService;

    @PostMapping("register")
    public AjaxResult register(@RequestBody StoreAccountVo account) {
        return success(platformStoreAccountService.register(account));
    }

    @PostMapping("login")
    public AjaxResult login(@RequestBody StoreAccountVo account) {
        AjaxResult ajax = AjaxResult.success("登陆成功");
        // 生成令牌
        String token = loginService.login(account.getMobile(), account.getPassword());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }

    @PostMapping("resetpwd")
    public AjaxResult resetpwd(@RequestBody StoreAccountVo account) {
        return success(platformStoreAccountService.resetpwd(account));
    }

    /**
     * 查询店家账号列表
     */
    @PreAuthorize("@ss.hasPermi('platform:account:list')")
    @GetMapping("/list")
    public TableDataInfo list(StoreAccount platformStoreAccount) {
        startPage();
        List<StoreAccount> list = platformStoreAccountService.selectStoreAccountList(platformStoreAccount);
        return getDataTable(list);
    }

    /**
     * 导出店家账号列表
     */
    @PreAuthorize("@ss.hasPermi('platform:account:export')")
    @Log(title = "店家账号", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, StoreAccount platformStoreAccount) {
        List<StoreAccount> list = platformStoreAccountService.selectStoreAccountList(platformStoreAccount);
        ExcelUtil<StoreAccount> util = new ExcelUtil<StoreAccount>(StoreAccount.class);
        util.exportExcel(response, list, "店家账号数据");
    }

    /**
     * 获取店家账号详细信息
     */
    @PreAuthorize("@ss.hasPermi('platform:account:query')")
    @GetMapping(value = "/{storeid}")
    public AjaxResult getInfo(@PathVariable("storeid") Long storeid) {
        return success(platformStoreAccountService.selectStoreAccountByStoreid(storeid));
    }

    /**
     * 新增店家账号
     */
    @PreAuthorize("@ss.hasPermi('platform:account:add')")
    @Log(title = "店家账号", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody StoreAccount platformStoreAccount) {
        return toAjax(platformStoreAccountService.insertStoreAccount(platformStoreAccount));
    }

    /**
     * 修改店家账号
     */
    @PreAuthorize("@ss.hasPermi('platform:account:edit')")
    @Log(title = "店家账号", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody StoreAccount platformStoreAccount) {
        return toAjax(platformStoreAccountService.updateStoreAccount(platformStoreAccount));
    }

    /**
     * 删除店家账号
     */
    @PreAuthorize("@ss.hasPermi('platform:account:remove')")
    @Log(title = "店家账号", businessType = BusinessType.DELETE)
    @DeleteMapping("/{storeids}")
    public AjaxResult remove(@PathVariable Long[] storeids) {
        return toAjax(platformStoreAccountService.deleteStoreAccountByStoreids(storeids));
    }
}
