package com.ruoyi.framework.web.service;

import com.ruoyi.common.core.domain.entity.SysUser;
import com.ruoyi.common.core.domain.model.LoginUser;
import com.ruoyi.common.enums.UserStatus;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.framework.security.TypeUsernamePasswordAuthenticationToken;
import com.ruoyi.framework.security.context.AuthenticationContextHolder;
import com.ruoyi.store.domain.StoreAccount;
import com.ruoyi.store.domain.StoreLoginUser;
import com.ruoyi.store.service.IStoreAccountService;
import com.ruoyi.system.service.ISysUserService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

/**
 * 用户验证处理
 *
 * @author ruoyi
 */
@Service
public class UserDetailsServiceImpl implements UserDetailsService
{
    private static final Logger log = LoggerFactory.getLogger(UserDetailsServiceImpl.class);

    @Autowired
    private ISysUserService userService;

    @Autowired
    private SysPasswordService passwordService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private IStoreAccountService storeAccountService;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {

        if (AuthenticationContextHolder.getContext() instanceof TypeUsernamePasswordAuthenticationToken) {
            TypeUsernamePasswordAuthenticationToken token = (TypeUsernamePasswordAuthenticationToken) AuthenticationContextHolder.getContext();
            String rawPassword = token.getCredentials().toString();
            switch (token.getType()) {
                case store: {
                    StoreAccount storeAccount = storeAccountService.selectAccountByMobile(username);
                    if (StringUtils.isNull(storeAccount)) {
                        log.info(StringUtils.format("{}不存在{}", token.getType().getRemark(), username));
                        throw new ServiceException(token.getType().getRemark() + "或密码错误");
                    }
                    if (!SecurityUtils.matchesPassword(rawPassword, storeAccount.getPassword())) {
                        throw new ServiceException(token.getType().getRemark() + "或密码错误");
                    }
                    return createLoginUser(storeAccount);
                }
            }
            log.error("无法识别认证类型：" + AuthenticationContextHolder.getContext().getClass());
            throw new ServiceException("系统异常");
        } else {

            SysUser user = userService.selectUserByUserName(username);
            if (StringUtils.isNull(user)) {
                log.info("登录用户：{} 不存在.", username);
                throw new ServiceException("登录用户：" + username + " 不存在");
            } else if (UserStatus.DELETED.getCode().equals(user.getDelFlag())) {
                log.info("登录用户：{} 已被删除.", username);
                throw new ServiceException("对不起，您的账号：" + username + " 已被删除");
            } else if (UserStatus.DISABLE.getCode().equals(user.getStatus())) {
                log.info("登录用户：{} 已被停用.", username);
                throw new ServiceException("对不起，您的账号：" + username + " 已停用");
            }

            passwordService.validate(user);

            return createLoginUser(user);
        }
    }

    private UserDetails createLoginUser(StoreAccount storeAccount) {
        return new StoreLoginUser(storeAccount);
    }

    public UserDetails createLoginUser(SysUser user) {
        return new LoginUser(user.getUserId(), user.getDeptId(), user, permissionService.getMenuPermission(user));
    }
}
