package com.ruoyi.framework.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.framework.domain.Sms;
import com.ruoyi.framework.mapper.SmsMapper;
import com.ruoyi.framework.service.ISmsService;
import org.apache.commons.lang3.RandomStringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 短信验证码Service业务层处理
 *
 * @author ruoyi
 * @date 2023-02-09
 */
@Service
public class SmsServiceImpl implements ISmsService {
    @Autowired
    private SmsMapper smsMapper;

    /**
     * 查询短信验证码
     *
     * @param id 短信验证码主键
     * @return 短信验证码
     */
    @Override
    public Sms selectSmsById(Long id) {
        return smsMapper.selectSmsById(id);
    }

    /**
     * 查询短信验证码列表
     *
     * @param Sms 短信验证码
     * @return 短信验证码
     */
    @Override
    public List<Sms> selectSmsList(Sms Sms) {
        return smsMapper.selectSmsList(Sms);
    }

    /**
     * 新增短信验证码
     *
     * @param Sms 短信验证码
     * @return 结果
     */
    @Override
    public int insertSms(Sms Sms) {
        return smsMapper.insertSms(Sms);
    }

    /**
     * 修改短信验证码
     *
     * @param Sms 短信验证码
     * @return 结果
     */
    @Override
    public int updateSms(Sms Sms) {
        return smsMapper.updateSms(Sms);
    }

    /**
     * 批量删除短信验证码
     *
     * @param ids 需要删除的短信验证码主键
     * @return 结果
     */
    @Override
    public int deleteSmsByIds(Long[] ids) {
        return smsMapper.deleteSmsByIds(ids);
    }

    /**
     * 删除短信验证码信息
     *
     * @param id 短信验证码主键
     * @return 结果
     */
    @Override
    public int deleteSmsById(Long id) {
        return smsMapper.deleteSmsById(id);
    }

    /**
     * 检查手机号是否存在有效短信验证码
     *
     * @return
     */
    @Override
    public Sms querySms(String mobile, String code) {
        LambdaQueryWrapper<Sms> wrapper = new LambdaQueryWrapper<>();
        Date d = new Date();
        wrapper.select(Sms::getId).eq(Sms::getMobile, mobile).le(Sms::getSendtime, d).ge(Sms::getDeadtime, d);
        if (code != null) {
            wrapper.eq(Sms::getCode, code);
        }
        return smsMapper.selectOne(wrapper);
    }

    @Override
    public String send(String mobile, Integer smsTime) {
        if (querySms(mobile, null) != null) {
            return "短信发送过于频繁";
        } else {
            String code = RandomStringUtils.randomNumeric(6);
            Sms newSms = new Sms();
            newSms.setMobile(mobile);
            newSms.setCode(code);
            //TODO 发送验证码成功

            newSms.setSendtime(new Date());
            newSms.setDeadtime(DateUtils.addSeconds(newSms.getSendtime(), smsTime));
            smsMapper.insert(newSms);
            return "短信验证码发送成功";
        }
    }
}
