package com.ruoyi.platform.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.platform.domain.PlatformAddress;
import com.ruoyi.platform.mapper.PlatformAddressMapper;
import com.ruoyi.platform.service.IPlatformAddressService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;

/**
 * 收货地址Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-13
 */
@Service
public class PlatformAddressServiceImpl implements IPlatformAddressService {
    @Autowired
    private PlatformAddressMapper platformAddressMapper;

    /**
     * 查询收货地址
     *
     * @param id 收货地址主键
     * @return 收货地址
     */
    @Override
    public PlatformAddress selectPlatformAddressById(Long id) {
        return platformAddressMapper.selectById(id);
    }

    /**
     * 查询收货地址列表
     *
     * @param platformAddress 收货地址
     * @return 收货地址
     */
    @Override
    public List<PlatformAddress> selectPlatformAddressList(PlatformAddress platformAddress) {
        LambdaQueryWrapper<PlatformAddress> wrapper = new LambdaQueryWrapper<>();
        if (platformAddress.getConsignee() != null) {
            wrapper.like(PlatformAddress::getConsignee, platformAddress.getAddress());
        }
        wrapper.eq(PlatformAddress::getUserId, platformAddress.getUserId());
        return platformAddressMapper.selectList(wrapper);
    }

    /**
     * 新增收货地址
     *
     * @param platformAddress 收货地址
     * @return 结果
     */
    @Override
    public int insertPlatformAddress(PlatformAddress platformAddress) {
        platformAddress.setCreateTime(DateUtils.getNowDate());
        return platformAddressMapper.insert(platformAddress);
    }

    /**
     * 修改收货地址
     *
     * @param platformAddress 收货地址
     * @return 结果
     */
    @Override
    public int updatePlatformAddress(PlatformAddress platformAddress) {
        return platformAddressMapper.updateById(platformAddress);
    }

    /**
     * 批量删除收货地址
     *
     * @param ids 需要删除的收货地址主键
     * @return 结果
     */
    @Override
    public int deletePlatformAddressByIds(Long[] ids) {
        return platformAddressMapper.deleteBatchIds(Arrays.asList(ids));
    }

    /**
     * 删除收货地址信息
     *
     * @param id 收货地址主键
     * @return 结果
     */
    @Override
    public int deletePlatformAddressById(Long id) {
        return platformAddressMapper.deleteById(id);
    }
}
