package com.ruoyi.platform.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.platform.domain.PlatformFollower;
import com.ruoyi.platform.mapper.PlatformFollowerMapper;
import com.ruoyi.platform.service.IPlatformFollowerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;

/**
 * 粉丝Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-13
 */
@Service
public class PlatformFollowerServiceImpl implements IPlatformFollowerService {
    @Autowired
    private PlatformFollowerMapper platformFollowerMapper;

    /**
     * 查询粉丝
     *
     * @param id 粉丝主键
     * @return 粉丝
     */
    @Override
    public PlatformFollower selectPlatformFollowerById(Long id) {
        return platformFollowerMapper.selectById(id);
    }

    /**
     * 查询粉丝列表
     *
     * @param platformFollower 粉丝
     * @return 粉丝
     */
    @Override
    public List<PlatformFollower> selectPlatformFollowerList(Long userId) {
        return platformFollowerMapper.selectPlatformFollowerList(userId);
    }

    /**
     * 新增粉丝
     *
     * @param platformFollower 粉丝
     * @return 结果
     */
    @Override
    public int insertPlatformFollower(PlatformFollower platformFollower) {
        platformFollower.setCreateTime(DateUtils.getNowDate());
        return platformFollowerMapper.insert(platformFollower);
    }

    /**
     * 修改粉丝
     *
     * @param platformFollower 粉丝
     * @return 结果
     */
    @Override
    public int updatePlatformFollower(PlatformFollower platformFollower) {
        return platformFollowerMapper.updateById(platformFollower);
    }

    /**
     * 批量删除粉丝
     *
     * @param ids 需要删除的粉丝主键
     * @return 结果
     */
    @Override
    public int deletePlatformFollowerByIds(Long[] ids) {
        return platformFollowerMapper.deleteBatchIds(Arrays.asList(ids));
    }

    /**
     * 删除粉丝信息
     *
     * @param id 粉丝主键
     * @return 结果
     */
    @Override
    public int deletePlatformFollowerById(Long id) {
        return platformFollowerMapper.deleteById(id);
    }
}
