package com.ruoyi.store.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.framework.domain.Sms;
import com.ruoyi.framework.service.ISmsService;
import com.ruoyi.store.domain.StoreAccount;
import com.ruoyi.store.domain.vo.StoreAccountVo;
import com.ruoyi.store.mapper.StoreAccountMapper;
import com.ruoyi.store.service.IStoreAccountService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 店家账号Service业务层处理
 *
 * @author ruoyi
 * @date 2023-02-10
 */
@Service
public class StoreAccountServiceImpl implements IStoreAccountService {
    @Autowired
    private StoreAccountMapper storeAccountMapper;

    @Autowired
    private ISmsService smsService;

    /**
     * 查询店家账号
     *
     * @param storeid 店家账号主键
     * @return 店家账号
     */
    @Override
    public StoreAccount selectStoreAccountByStoreid(Long storeid) {
        return storeAccountMapper.selectStoreAccountByStoreid(storeid);
    }

    /**
     * 查询店家账号列表
     *
     * @param StoreAccount 店家账号
     * @return 店家账号
     */
    @Override
    public List<StoreAccount> selectStoreAccountList(StoreAccount StoreAccount) {
        return storeAccountMapper.selectStoreAccountList(StoreAccount);
    }

    /**
     * 新增店家账号
     *
     * @param StoreAccount 店家账号
     * @return 结果
     */
    @Override
    public int insertStoreAccount(StoreAccount StoreAccount) {
        return storeAccountMapper.insertStoreAccount(StoreAccount);
    }

    /**
     * 修改店家账号
     *
     * @param StoreAccount 店家账号
     * @return 结果
     */
    @Override
    public int updateStoreAccount(StoreAccount StoreAccount) {
        return storeAccountMapper.updateStoreAccount(StoreAccount);
    }

    /**
     * 批量删除店家账号
     *
     * @param storeids 需要删除的店家账号主键
     * @return 结果
     */
    @Override
    public int deleteStoreAccountByStoreids(Long[] storeids) {
        return storeAccountMapper.deleteStoreAccountByStoreids(storeids);
    }

    /**
     * 删除店家账号信息
     *
     * @param storeid 店家账号主键
     * @return 结果
     */
    @Override
    public int deleteStoreAccountByStoreid(Long storeid) {
        return storeAccountMapper.deleteStoreAccountByStoreid(storeid);
    }

    @Override
    public StoreAccount selectAccountByMobile(String mobile) {
        LambdaQueryWrapper<StoreAccount> wrapper = new LambdaQueryWrapper<>();
        wrapper.select(StoreAccount::getStoreid, StoreAccount::getMobile, StoreAccount::getPassword).eq(StoreAccount::getMobile, mobile);
        return storeAccountMapper.selectOne(wrapper);
    }

    @Override
    public String register(StoreAccountVo account) {
        //检查验证码是否有效
        Sms sms = smsService.querySms(account.getMobile(), account.getVerificationCode());
        if (sms != null) {
            sms.setDeadtime(new Date());
            smsService.updateSms(sms);
            if (selectAccountByMobile(account.getMobile()) != null) {
                return "手机号已注册";
            } else {
                StoreAccount newAccount = new StoreAccount();
                newAccount.setMobile(account.getMobile());
                newAccount.setPassword(SecurityUtils.encryptPassword(account.getPassword()));
                newAccount.setStatus(1L);
                newAccount.setRegisterdate(new Date());
                newAccount.setNickname(newAccount.getMobile());
                newAccount.setSex(0L);
                if (storeAccountMapper.insert(newAccount) > 0) {
                    return "注册成功";
                } else {
                    return "注册失败";
                }
            }
        } else {
            return "手机号或验证码错误";
        }
    }

    @Override
    public String resetpwd(StoreAccountVo account) {
        //检查验证码是否有效
        Sms sms = smsService.querySms(account.getMobile(), account.getVerificationCode());
        if (sms != null) {
            sms.setDeadtime(new Date());
            smsService.updateSms(sms);
            StoreAccount storeAccount = selectAccountByMobile(account.getMobile());
            storeAccount.setPassword(SecurityUtils.encryptPassword(account.getPassword()));
            if (storeAccountMapper.updateById(storeAccount) > 0) {
                return "密码重置成功";
            } else {
                return "密码重置失败";
            }
        } else {
            return "手机号或验证码错误";
        }
    }
}
